{% extends "base.html" %}

{% block contents %}
    <section class="main">
        Premi il pulsante qui sotto e accedi con <b>il tuo account Unimore</b> per accedere al gruppo!
    </section>
    <section class="buttons">
        <a class="button" href="{{ url_for("page_login") }}">
            Verifica
        </a>
    </section>
    <section id="privacy" class="smol-box">
        Proseguendo, acconsenti all'uso dei tuoi dati secondo l'<a href="{{ url_for("page_privacy") }}">informativa
        sulla privacy</a>.
    </section>
{% endblock %}